@@ -1,5 +1,9 @@
 
 /* changes:
+ * 1.12:
+ *   - allow y/n for Y/N
+ *   - fix command line parsing
+ *
  * 1.11:
  *   - 'echo $PWD' -> 'pwd' (suggested by Tomi Ollila)
  *   - suggest use of ssh-agent in readme (comment by Thomas Kronseder)
@@ -1048,45 +1052,47 @@ int main (int argc, char * argv[])
 
   /* parse arguments
    */
+
+  /* drop program name 
+   */
   --argc; ++argv;
 
-  while (argc > 0)
+  while (argc > 0 && argv[0][0] == '-')
     {
-      if (argv[0][0] == '-')
+      switch (argv[0][1])
 	{
-	  switch (argv[0][1])
-	    {
-	    case 'l':
-	      --argc; ++argv;
-	      if (argc < 1)
-		usage(FALSE);
-	      if (argv[0][0] == '-')
-		usage(FALSE);
-	      usr_str = my_strdup (argv[0]);
-	      break;
-	    case 'p':
-	      --argc; ++argv;
-	      if (argc < 1)
-		usage(FALSE);
-	      if (argv[0][0] == '-')
-		usage(FALSE);
-	      port = (unsigned int) (atoi (argv[0]));
-	      break;
-	    case 'h':
-	      usage(TRUE);
-	      break;
-	    case 'v':
-	      opt_debug = TRUE;
-	      break;
-	    default:
-	      usage(FALSE);
-	      break;
-	    }
+	case 'l':
+	  --argc; ++argv;
+	  if (argc < 1)
+	    usage(FALSE);
+	  if (argv[0][0] == '-')
+	    usage(FALSE);
+	  usr_str = my_strdup (argv[0]);
+	  break;
+	case 'p':
+	  --argc; ++argv;
+	  if (argc < 1)
+	    usage(FALSE);
+	  if (argv[0][0] == '-')
+	    usage(FALSE);
+	  port = (unsigned int) (atoi (argv[0]));
+	  break;
+	case 'h':
+	  usage(TRUE);
+	  break;
+	case 'v':
+	  opt_debug = TRUE;
+	  break;
+	default:
+	  usage(FALSE);
+	  break;
 	}
-      if (argc == 1)
-	hst_str = my_strdup (argv[0]);
       --argc; ++argv;
     }
+  if (argc == 1)
+    hst_str = my_strdup (argv[0]);
+  else
+    usage(FALSE);
 
   if (usr_str == NULL)
     {
