@@ -855,6 +855,12 @@ int user_handler(int mode, int master, int input_pipe[], int output_pipe[],
 	  if (NULL != strstr (line, "Received signal"))
 	    continue;
 	  
+	  /* blurb 
+	   */
+	  if (NULL != strstr (line, "OpenSSH") && 
+	      NULL != strstr (line, "SSH protocols"))
+	    continue;
+	  
 	  /* new host
 	   */
 	  if (NULL != strstr (line, "list of known hosts"))
@@ -875,19 +881,22 @@ int user_handler(int mode, int master, int input_pipe[], int output_pipe[],
 	  
 	  /* some other error
 	   */
-	  fprintf(stderr, "Continue (Y/N) ? ");
+	  fprintf(stderr, "Continue (Y/n) ? ");
 	  while (1 == 1) 
 	    {
 	      c = getc(stdin);
-	      if (c == 'Y') 
+	      if (c == 'Y' || c == 'y' || c == '\n') 
 		break;
-	      if (c == 'N') {
+	      else if (c == 'N' || c == 'n') {
 		close(input_pipe[0]);
 		close(inerr_pipe[0]);
 		close(output_pipe[1]);
 		close(master);
 		return -2;
 	      }
+	      else {
+		fprintf(stderr, "Continue (Y/n) ? ");
+	      }
 	    }
 	  continue;
 	}
